==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TemplateColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescriptionMetadata } from "./TemplateCellUpdatingEventArgsDescriptionMetadata";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { TemplateColumnDescription } from "./TemplateColumnDescription";
/**
 * @hidden
 */
export let TemplateColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateColumnDescriptionMetadata extends Base {
        static e(a) {
            a.item("TemplateRef", "(w:Template,wf:Template,xam:Template)DataRef:String");
        }
        static b(a) {
            if (TemplateColumnDescriptionMetadata.a == null) {
                TemplateColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateColumnDescriptionMetadata.c(TemplateColumnDescriptionMetadata.a);
            }
            if (a.k(TemplateColumnDescriptionMetadata.a)) {
                return;
            }
            a.ab(TemplateColumnDescriptionMetadata.a);
            TemplateCellUpdatingEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("CellUpdatingRef", "EventRef::cellUpdating");
            TemplateColumnDescriptionMetadata.e(a);
        }
        static d(a) {
            TemplateColumnDescriptionMetadata.b(a);
            a.ad("TemplateColumn", () => new TemplateColumnDescription());
            a.ac("TemplateColumn", TemplateColumnDescriptionMetadata.a);
        }
    }
    TemplateColumnDescriptionMetadata.$t = markType(TemplateColumnDescriptionMetadata, 'TemplateColumnDescriptionMetadata');
    TemplateColumnDescriptionMetadata.a = null;
    return TemplateColumnDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TemplateColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellUpdatingEventArgsDescriptionMetadata } from "./TemplateCellUpdatingEventArgsDescriptionMetadata";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { TemplateColumnDescription } from "./TemplateColumnDescription";
/**
 * @hidden
 */
export let TemplateColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateColumnDescriptionMetadata extends Base {
        static e(a) {
            a.item("TemplateRef", "(w:Template,wf:Template,xam:Template)DataRef:String");
        }
        static b(a) {
            if (TemplateColumnDescriptionMetadata.a == null) {
                TemplateColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateColumnDescriptionMetadata.c(TemplateColumnDescriptionMetadata.a);
            }
            if (a.k(TemplateColumnDescriptionMetadata.a)) {
                return;
            }
            a.ac(TemplateColumnDescriptionMetadata.a);
            TemplateCellUpdatingEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("CellUpdatingRef", "EventRef::cellUpdating");
            TemplateColumnDescriptionMetadata.e(a);
        }
        static d(a) {
            TemplateColumnDescriptionMetadata.b(a);
            a.ae("TemplateColumn", () => new TemplateColumnDescription());
            a.ad("TemplateColumn", TemplateColumnDescriptionMetadata.a);
        }
    }
    TemplateColumnDescriptionMetadata.$t = markType(TemplateColumnDescriptionMetadata, 'TemplateColumnDescriptionMetadata');
    TemplateColumnDescriptionMetadata.a = null;
    return TemplateColumnDescriptionMetadata;
})();
